@@ -1,5 +1,4 @@
 package List::Generator;
-use warnings;
 BEGIN {require List::Gen}
 
 =head1 NAME
@@ -8,7 +7,7 @@ List::Generator - provides functions for generating lists
 
 =head1 VERSION
 
-version 0.976_04
+version 0.91
 
 =head1 SYNOPSIS
 
@@ -25,10 +24,6 @@ every way.
 
     say "@$fib[0 .. 10]"; # 0 1 1 2 3 5 8 13 21 34 55
 
-    list(1 .. 5)->map('*2')->say; # 2 4 6 8 10
-
-    <1..>->zip('.' => <a..>)->say(5); # 1a 2b 3c 4d 5e
-
 each line below prints C< '1 9 25 49 81' >:
 
     functions:           (gen {$_**2} filter {$_ % 2} 1, 10)->say;
@@ -45,8 +40,6 @@ each line below prints C< '1 9 25 49 81' >:
 
 =item * see L<List::Gen> for core documentation.
 
-=item * see L<List::Gen::Benchmark> for performance tips.
-
 =item * see L<List::Gen::Cookbook> for usage tips.
 
 =item * see L<List::Gen::Haskell> for an experimental implementation of haskell's
